@@ -41,7 +41,7 @@ getIRIS<-function(fn, skip=0)
         jim$mo[i] = d1[2]
         jim$dom[i] = d1[3]
         jim$hr[i] = t1[1]
-        jim$mi=t1[2]
+        jim$mi[i]=t1[2]
         jim$sec[i] = t1[3]
         jim$lat[i] = lat
         jim$lon[i] = lon
