@@ -8,8 +8,10 @@ function(NPP=6, asta="",acomp="", theday=1, hr=0 )
   
   if(missing(theday)) {  theday=1 }
   if(missing(hr)) {  hr=0  }
-  
-  print("Doing postscript")
+     oldpar <- par(no.readonly = TRUE)
+      on.exit(par(oldpar))
+
+  message("Doing postscript")
   plname = paste(sep=".", "longfft", asta, acomp, formatC(theday, format="d", width=3,flag="0") , formatC(hr, format="d", width=2,flag="0"))
   RPMG::jpostscript(plname , P=c(14, 14) )
   par(mfrow=c(NPP,1))
