@@ -3,10 +3,16 @@ winseis24<-function(pjj, pch=3, col='red' )
   if(missing(col)) col = 'red'
   if(missing(pch))  pch=3 
 
-  
+##   pch=3; col='red'
 ###########  after plotting plotseis24, interact with plot by clicking
   ###  pjj y=tick marks in the Y direction y axis
-  ###      x=x-axis
+###      x=x-axis
+
+  oldpar <- par(no.readonly = TRUE)
+      on.exit(par(oldpar))
+
+  par(pjj$mypar)
+  
   LL = locator(pch=pch, type="p", col=col, cex=2)
 
   tix = pjj$y
