@@ -5,7 +5,7 @@
 
 #define MAX(a,b) ((a) >= (b) ? (a) : (b))
 #define ABS(a) ((a) < (0) ? -(a) : (a))
-#define PI 3.14159265358979
+#define JMLPI 3.14159265358979
 #define SWAP(a,b) tempr=(a);(a)=(b);(b)=tempr
 
 #define NR_END 1
